@@ -37,7 +37,7 @@
 
 /// Identifies which sort of serial port each device represents.
 #[repr(C)]
-#[derive(Copy, Clone, PartialEq, Eq)]
+#[derive(Copy, Clone, Debug, PartialEq, Eq)]
 pub enum DeviceType {
 	/// An RS-232 interface
 	Rs232,
@@ -55,7 +55,7 @@ pub enum DeviceType {
 /// Whether each word contains a parity bit, and if so, how it is
 /// calculated.
 #[repr(C)]
-#[derive(Copy, Clone, PartialEq, Eq)]
+#[derive(Copy, Clone, Debug, PartialEq, Eq)]
 pub enum Parity {
 	/// An extra parity bit is added to each word. There will be an odd
 	/// number of `1` bits in the new word (old word + parity bit). This
@@ -73,7 +73,7 @@ pub enum Parity {
 
 /// Whether to use hardware handshaking lines.
 #[repr(C)]
-#[derive(Copy, Clone, PartialEq, Eq)]
+#[derive(Copy, Clone, Debug, PartialEq, Eq)]
 pub enum Handshaking {
 	/// No hardware handshaking - bytes will be dropped if there is an
 	/// overflow
@@ -94,7 +94,7 @@ pub enum Handshaking {
 
 /// The number of stop bits after each word.
 #[repr(C)]
-#[derive(Copy, Clone, PartialEq, Eq)]
+#[derive(Copy, Clone, Debug, PartialEq, Eq)]
 pub enum StopBits {
 	/// One stop bit is added to each word
 	One,
@@ -104,7 +104,7 @@ pub enum StopBits {
 
 /// The number of data bits in each word sent or received by the UART.
 #[repr(C)]
-#[derive(Copy, Clone, PartialEq, Eq)]
+#[derive(Copy, Clone, Debug, PartialEq, Eq)]
 pub enum DataBits {
 	/// Each word comprises 7 data bits (plus start bit, stop bits and any
 	/// parity bits)
@@ -116,7 +116,7 @@ pub enum DataBits {
 
 /// A particular configuration for a serial port.
 #[repr(C)]
-#[derive(Clone)]
+#[derive(Clone, Debug, PartialEq, Eq)]
 pub struct Config {
 	/// The desired transmission speed, in bits per second (also known as
 	/// the 'baud rate'). Some hardware implementations allow a free choice
@@ -135,7 +135,7 @@ pub struct Config {
 
 /// Information about a particular serial device.
 #[repr(C)]
-#[derive(Clone)]
+#[derive(Clone, Debug, PartialEq, Eq)]
 pub struct DeviceInfo {
 	/// Some human-readable name for this serial device (e.g. `RS232` or
 	/// `USB0`)
